@@ -14,7 +14,7 @@ knitr::opts_chunk$set(
 ## ----include=FALSE------------------------------------------------------------
 library(bgms)
 data = Wenchuan[, 1:5]
-fit <- readRDS(system.file("extdata", "fit_5items.rds", package = "bgms"))
+fit = bgm(data, seed = 1234, chains = 2, display_progress = "none", verbose = FALSE)
 
 ## -----------------------------------------------------------------------------
 summary(fit)$pairwise
@@ -26,8 +26,10 @@ param_index = 1
 chains = lapply(fit$raw_samples$pairwise, function(mat) mat[, param_index])
 mcmc_obj = mcmc.list(lapply(chains, mcmc))
 
-traceplot(mcmc_obj, col = c("firebrick", "steelblue", "darkgreen", "goldenrod"), 
-          main = "Traceplot of pairwise[1]") 
+traceplot(mcmc_obj,
+  col = c("firebrick", "steelblue", "darkgreen", "goldenrod"),
+  main = "Traceplot of pairwise[1]"
+)
 
 ## -----------------------------------------------------------------------------
 coef(fit)$indicator
